==> rubocop_0.89.1+dfsg.orig.tar.xz: rubocop-0.89.1/spec/rubocop/cop/lint/mixed_regexp_capture_types_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Lint::MixedRegexpCaptureTypes do
  subject(:cop) { described_class.new(config) }

  let(:config) { RuboCop::Config.new }

  it 'registers an offense when both of named and numbered captures are used' do
    expect_offense(<<~RUBY)
      /(?<foo>bar)(baz)/
      ^^^^^^^^^^^^^^^^^^ Do not mix named captures and numbered captures in a Regexp literal.
    RUBY
  end

  it 'does not register offense to a regexp with named capture only' do
    expect_no_offenses(<<~RUBY)
      /(?<foo>foo?<bar>bar)/
    RUBY
  end

  it 'does not register offense to a regexp with numbered capture only' do
    expect_no_offenses(<<~RUBY)
      /(foo)(bar)/
    RUBY
  end

  it 'does not register offense to a regexp with named capture and ' \
     'non-capturing group' do
    expect_no_offenses(<<~RUBY)
      /(?<foo>bar)(?:bar)/
    RUBY
  end

  # See https://github.com/rubocop-hq/rubocop/issues/8083
  it 'does not register offense when using a Regexp cannot be processed by regexp_parser gem' do
    expect_no_offenses(<<~'RUBY')
      /data = ({"words":.+}}}[^}]*})/m
    RUBY
  end

  # RuboCop does not know a value of variables that it will contain in the regexp literal.
  # For example, `/(?<foo>#{var}*)` is interpreted as `/(?<foo>*)`.
  # So it does not offense when variables are used in regexp literals.
  context 'when containing a non-regexp literal' do
    it 'does not register an offence when containing a lvar' do
      expect_no_offenses(<<~'RUBY')
        var = '(\d+)'
        /(?<foo>#{var}*)/
      RUBY
    end

    it 'does not register an offence when containing a ivar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{@var}*)/
      RUBY
    end

    it 'does not register an offence when containing a cvar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{@@var}*)/
      RUBY
    end

    it 'does not register an offence when containing a gvar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{$var}*)/
      RUBY
    end

    it 'does not register an offence when containing a method' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{do_something}*)/
      RUBY
    end

    it 'does not register an offence when containing a constant' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{CONST}*)/
      RUBY
    end
  end
end

==> rubocop_1.39.0+dfsg.orig.tar.xz: rubocop-1.39.0/spec/rubocop/cop/lint/mixed_regexp_capture_types_spec.rb <==
# frozen_string_literal: true

RSpec.describe RuboCop::Cop::Lint::MixedRegexpCaptureTypes, :config do
  it 'registers an offense when both of named and numbered captures are used' do
    expect_offense(<<~RUBY)
      /(?<foo>bar)(baz)/
      ^^^^^^^^^^^^^^^^^^ Do not mix named captures and numbered captures in a Regexp literal.
    RUBY
  end

  it 'does not register offense to a regexp with named capture only' do
    expect_no_offenses(<<~RUBY)
      /(?<foo>foo?<bar>bar)/
    RUBY
  end

  it 'does not register offense to a regexp with numbered capture only' do
    expect_no_offenses(<<~RUBY)
      /(foo)(bar)/
    RUBY
  end

  it 'does not register offense to a regexp with named capture and non-capturing group' do
    expect_no_offenses(<<~RUBY)
      /(?<foo>bar)(?:bar)/
    RUBY
  end

  # See https://github.com/rubocop/rubocop/issues/8083
  it 'does not register offense when using a Regexp cannot be processed by regexp_parser gem' do
    expect_no_offenses(<<~'RUBY')
      /data = ({"words":.+}}}[^}]*})/m
    RUBY
  end

  # RuboCop does not know a value of variables that it will contain in the regexp literal.
  # For example, `/(?<foo>#{var}*)` is interpreted as `/(?<foo>*)`.
  # So it does not offense when variables are used in regexp literals.
  context 'when containing a non-regexp literal' do
    it 'does not register an offense when containing a lvar' do
      expect_no_offenses(<<~'RUBY')
        var = '(\d+)'
        /(?<foo>#{var}*)/
      RUBY
    end

    it 'does not register an offense when containing a ivar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{@var}*)/
      RUBY
    end

    it 'does not register an offense when containing a cvar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{@@var}*)/
      RUBY
    end

    it 'does not register an offense when containing a gvar' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{$var}*)/
      RUBY
    end

    it 'does not register an offense when containing a method' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{do_something}*)/
      RUBY
    end

    it 'does not register an offense when containing a constant' do
      expect_no_offenses(<<~'RUBY')
        /(?<foo>#{CONST}*)/
      RUBY
    end
  end
end
